@@ -845,10 +845,14 @@ EAPI int
 ecore_event_evas_shutdown(void)
 {
    size_t i;
+   Ecore_Event_Last *eel;
 
    if (--_ecore_event_evas_init_count != 0)
      return _ecore_event_evas_init_count;
 
+   EINA_LIST_FREE(_last_events, eel)
+      free(eel);
+
    eina_hash_free(_window_hash);
    _window_hash = NULL;
    for (i = 0; i < sizeof(ecore_event_evas_handlers) / sizeof(Ecore_Event_Handler *); i++)
