@@ -101,6 +101,7 @@ static void *hash_array_string_add(void *hash, const char *key, void *data);
 
 static Eina_Bool disable_cache;
 static Eina_Bool run_in_tree;
+static int relaunch_try = 0;
 
 EAPI int EFREET_EVENT_ICON_CACHE_UPDATE = 0;
 EAPI int EFREET_EVENT_DESKTOP_CACHE_UPDATE = 0;
@@ -117,9 +118,19 @@ _ipc_launch(void)
    char buf[PATH_MAX];
    int num;
    int try_gap = 10000; // 10ms
-   int tries = 200; // 200 * 10ms == 2sec
+   int tries = 1000; // 1000 * 10ms == 10sec
    const char *s;
 
+   if (relaunch_try == 0)
+     {
+        ipc = ecore_ipc_server_connect(ECORE_IPC_LOCAL_USER, "efreetd", 0, NULL);
+        if (ipc)
+          {
+             relaunch_try++;
+             return;
+          }
+     }
+   relaunch_try--;
    s = getenv("EFREETD_CONNECT_TRIES");
    if (s)
      {
@@ -144,13 +155,14 @@ _ipc_launch(void)
         usleep(try_gap);
         ipc = ecore_ipc_server_connect(ECORE_IPC_LOCAL_USER, "efreetd", 0, NULL);
      }
-   if (!ipc) ERR("Timeout in trying to start and then connect to efrteed");
+   if (!ipc) ERR("Timeout in trying to start and then connect to efreetd");
 }
 
 static Eina_Bool
 _cb_server_add(void *data EINA_UNUSED, int type EINA_UNUSED, void *event)
 {
    IPC_HEAD(Add);
+   relaunch_try--;
    return ECORE_CALLBACK_DONE;
 }
 
@@ -180,7 +192,6 @@ _cb_server_reconnect(void *data EINA_UNUSED)
 static Eina_Bool
 _cb_server_del(void *data EINA_UNUSED, int type EINA_UNUSED, void *event)
 {
-   static double last_del = 0.0;
    double t;
    IPC_HEAD(Del);
    ipc = NULL;
@@ -194,15 +205,10 @@ _cb_server_del(void *data EINA_UNUSED, int type EINA_UNUSED, void *event)
         free(address);
         return EINA_FALSE;
      }
-   t = ecore_time_get();
-   if ((t - last_del) < 0.5)
-     {
-        if (reconnect_timer) ecore_timer_del(reconnect_timer);
-        reconnect_timer = ecore_timer_add(0.5, _cb_server_reconnect, NULL);
-     }
-   else
-     _cb_server_reconnect(NULL);
-   last_del = t;
+   // random 0.5 -> 1.0 sec from now
+   t = (((double)((rand() + (int)getpid()) & 0xff) / 255.0) * 0.5) + 0.5;
+   if (reconnect_timer) ecore_timer_del(reconnect_timer);
+   reconnect_timer = ecore_timer_add(t, _cb_server_reconnect, NULL);
    return ECORE_CALLBACK_DONE;
 }
 
