@@ -73,10 +73,6 @@
 #include <Efreet_Trash.h>
 #include <Ethumb_Client.h>
 
-#ifdef ELM_ELOCATION
-#include <Elocation.h>
-#endif
-
 #ifdef ELM_EMAP
 #include <EMap.h>
 #endif
@@ -87,6 +83,9 @@
 #ifdef EWAPI
 # undef EWAPI
 #endif
+#ifdef EAPI_WEAK
+# undef EAPI_WEAK
+#endif
 
 #ifdef _WIN32
 # ifdef EFL_BUILD
@@ -197,7 +196,7 @@ EAPI extern Elm_Version *elm_version;
 #include <elm_cache.h>
 #include <elm_calendar.h>
 /* this is elm_animation_view */
-#include <efl_ui_animation_view.h>
+#include <efl_ui_vg_animation.h>
 #include <elm_check.h>
 #include <elm_clock.h>
 #include <elm_cnp.h>
