@@ -108,6 +108,12 @@ _prepare_comp(Evas_Object_Protected_Data *obj,     //vector object
                                            EFL_GFX_COLORSPACE_ARGB8888,
                                            &pd->comp.stride);
         if (!pd->comp.pixels) ERR("Failed to map VG composite buffer");
+
+        //If composite method is SUBSTRACT or INTERSECT, Buffer needs initialize.
+        if (pd->comp.pixels &&
+            (pd->comp.method == EFL_GFX_VG_COMPOSITE_METHOD_MASK_SUBSTRACT ||
+             pd->comp.method == EFL_GFX_VG_COMPOSITE_METHOD_MASK_INTERSECT))
+          memset(pd->comp.pixels, init_buffer, pd->comp.length);
      }
    else
      {
@@ -206,6 +212,13 @@ _efl_canvas_vg_container_render_pre(Evas_Object_Protected_Data *vg_pd,
         if (flag & EFL_GFX_CHANGE_FLAG_MATRIX)
           child_nd->flags |= EFL_GFX_CHANGE_FLAG_MATRIX;
 
+        // Note: If Vg.Container has transparency, this is calculated by _evas_vg_render in Efl.Canvas.Vg.Object.
+        //       Therefore, there is no need to propagate the transparency of the container to the child.
+        //       However, if there is a composition target, the child must refer to the parent's opacity.
+        //       Because _evas_vg_render does not support opacity calculation for containers that need to be composited.
+        //       These things need to be refactored in a better way later.
+        c_a = !comp ? 255 : c_a;
+
         _evas_vg_render_pre(vg_pd, child,
                             engine, output, context, surface,
                             ctransform, c_a, comp, comp_method);
@@ -298,6 +311,12 @@ _efl_canvas_vg_container_children_get(Eo *obj EINA_UNUSED, Efl_Canvas_Vg_Contain
    return eina_list_iterator_new(pd->children);
 }
 
+static const Eina_List *
+_efl_canvas_vg_container_children_direct_get(Eo *obj EINA_UNUSED, Efl_Canvas_Vg_Container_Data *pd)
+{
+   return pd->children;
+}
+
 static Eina_Bool
 _efl_canvas_vg_container_efl_gfx_path_interpolate(Eo *obj, Efl_Canvas_Vg_Container_Data *pd, const Efl_VG *from, const Efl_VG *to, double pos_map)
 {
@@ -390,7 +409,7 @@ _efl_canvas_vg_container_efl_object_parent_set(Eo *obj,
 
 EOLIAN static Efl_VG *
 _efl_canvas_vg_container_efl_duplicate_duplicate(const Eo *obj,
-                                             Efl_Canvas_Vg_Container_Data *pd)
+                                                 Efl_Canvas_Vg_Container_Data *pd)
 {
    Eina_List *l;
    Efl_VG *child;
@@ -402,7 +421,11 @@ _efl_canvas_vg_container_efl_duplicate_duplicate(const Eo *obj,
    //Copy Composite
    if (pd->comp_target)
      {
+        /* OPTIMIZE: How to skip copying the target
+           if this target is linked to multiple sources?? */
         Eo * comp_target = efl_duplicate(pd->comp_target);
+
+        //FIXME: comp_target parent should be its own parent(duplicated obj this case)
         efl_parent_set(comp_target, container);
         efl_canvas_vg_node_comp_method_set(container, comp_target, pd->comp.method);
      }
@@ -410,6 +433,14 @@ _efl_canvas_vg_container_efl_duplicate_duplicate(const Eo *obj,
    //Copy Children
    EINA_LIST_FOREACH(pd->children, l, child)
      {
+        //Skip, We already copied composite target before.
+        if (efl_isa(child, MY_CLASS))
+          {
+             Efl_Canvas_Vg_Container_Data *pd2 =
+                efl_data_scope_get(child, MY_CLASS);
+             if (pd2->comp.src) continue;
+          }
+
         Efl_VG *eo = efl_duplicate(child);
         efl_parent_set(eo, container);
      }
@@ -457,8 +488,8 @@ efl_canvas_vg_container_blend_buffer_clear(Efl_VG *obj EINA_UNUSED, Efl_Canvas_V
    cd->blend.buffer = NULL;
 }
 
-EAPI Efl_VG*
-evas_vg_container_add(Efl_VG *parent)
+EAPI Evas_Vg_Container *
+evas_vg_container_add(Evas_Object *parent)
 {
    /* Warn it because the usage has been changed.
       We can remove this message after v1.21. */
