@@ -144,6 +144,8 @@ _efl_canvas_vg_object_root_node_set(Eo *eo_obj, Efl_Canvas_Vg_Object_Data *pd, E
    // detach/free the old root_node
    if (pd->user_entry && pd->user_entry->root)
      {
+        // drop any surface cache attached to it.
+        ENFN->ector_surface_cache_drop(_evas_engine_context(obj->layer->evas), pd->user_entry->root);
         efl_canvas_vg_node_vg_obj_set(pd->user_entry->root, NULL, NULL);
         efl_replace(&pd->user_entry->root, NULL);
      }
@@ -152,22 +154,20 @@ _efl_canvas_vg_object_root_node_set(Eo *eo_obj, Efl_Canvas_Vg_Object_Data *pd, E
      {
         if (!pd->user_entry)
           {
-             pd->user_entry = malloc(sizeof(Vg_User_Entry));
+             pd->user_entry = calloc(1, sizeof(Vg_User_Entry));
              if (!pd->user_entry)
                {
                   ERR("Failed to alloc user entry data while setting root node");
                   return;
                }
           }
-        pd->user_entry->w = pd->user_entry->h = 0;
+        else pd->user_entry->w = pd->user_entry->h = 0;
 
         efl_replace(&pd->user_entry->root, root_node);
         efl_canvas_vg_node_vg_obj_set(root_node, eo_obj, pd);
      }
    else if (pd->user_entry)
      {
-        // drop any surface cache attached to it.
-        ENFN->ector_surface_cache_drop(_evas_engine_context(obj->layer->evas), pd->user_entry->root);
         free(pd->user_entry);
         pd->user_entry = NULL;
      }
@@ -263,11 +263,13 @@ _efl_canvas_vg_object_efl_file_file_set(Eo *eo_obj, Efl_Canvas_Vg_Object_Data *p
              evas_object_change(eo_obj, obj);
              pd->vg_entry = NULL;
              evas_object_change(eo_obj, obj);
+             pd->changed = EINA_TRUE;
           }
      }
 
    Eina_Error err;
    err = efl_file_set(efl_super(eo_obj, MY_CLASS), file);
+
    if (err) return err;
 
    return 0;
@@ -290,8 +292,9 @@ _efl_canvas_vg_object_efl_file_load(Eo *eo_obj, Efl_Canvas_Vg_Object_Data *pd)
    pd->vg_entry = evas_cache_vg_entry_create(evas_object_evas_get(eo_obj),
                                              file, key,
                                              obj->cur->geometry.w,
-                                             obj->cur->geometry.h);
+                                             obj->cur->geometry.h, NULL);
    evas_object_change(eo_obj, obj);
+   pd->changed = EINA_TRUE;
 
    return 0;
 }
@@ -345,11 +348,19 @@ _efl_canvas_vg_object_efl_object_invalidate(Eo *eo_obj, Efl_Canvas_Vg_Object_Dat
    if (pd->user_entry)
      {
         Vg_User_Entry *user_entry = pd->user_entry;
-
         ENFN->ector_surface_cache_drop(ENC, user_entry->root);
         free(pd->user_entry);
      }
    pd->user_entry = NULL;
+
+   //Drop cache buffers
+   if (pd->vg_entry)
+     {
+        if (pd->ckeys[0])
+          ENFN->ector_surface_cache_drop(_evas_engine_context(obj->layer->evas), pd->ckeys[0]);
+        if (pd->ckeys[1])
+          ENFN->ector_surface_cache_drop(_evas_engine_context(obj->layer->evas), pd->ckeys[1]);
+     }
    evas_cache_vg_entry_del(pd->vg_entry);
 
    efl_invalidate(efl_super(eo_obj, MY_CLASS));
@@ -369,7 +380,7 @@ _efl_canvas_vg_object_efl_object_constructor(Eo *eo_obj, Efl_Canvas_Vg_Object_Da
 
    /* default root node */
    pd->obj = obj;
-   pd->root = efl_add_ref(EFL_CANVAS_VG_CONTAINER_CLASS, eo_obj);
+   pd->root = efl_add_ref(EFL_CANVAS_VG_CONTAINER_CLASS, NULL);
 
    eina_array_step_set(&pd->cleanup, sizeof(pd->cleanup), 8);
 
@@ -381,6 +392,12 @@ _efl_canvas_vg_object_efl_object_finalize(Eo *obj, Efl_Canvas_Vg_Object_Data *pd
 {
    Evas *e = evas_object_evas_get(obj);
 
+   /* Container must have a set parent after construction.
+      efl_add_ref() with a parent won't work this case 
+      because container needs some jobs in overriding parent_set()
+      after proper intialization. */
+   efl_parent_set(pd->root, obj);
+
    // TODO: If we start to have to many Evas_Object_VG per canvas, it may be nice
    // to actually have one event per canvas and one array per canvas to.
    efl_event_callback_add(e, EFL_CANVAS_SCENE_EVENT_RENDER_POST, _cleanup_reference, pd);
@@ -440,6 +457,15 @@ _evas_vg_render(Evas_Object_Protected_Data *obj, Efl_Canvas_Vg_Object_Data *pd,
                     memset(cd->blend.pixels, 0, cd->blend.length);
                }
 
+             //For recovery context
+             //FIXME: It may occur async issue?
+             int px, py, pw, ph, pstride;
+             void *ppixels = NULL;
+             ector_buffer_size_get(ector, &pw, &ph);
+             ector_buffer_pixels_get(ector, &ppixels, &px, &ph, &pstride);
+             Efl_Gfx_Colorspace pcspace = ector_buffer_cspace_get(ector);
+             ector_surface_reference_point_get(ector, &px, &py);
+
              // Buffer change
              ector_buffer_pixels_set(ector, cd->blend.pixels,
                                      w, h, cd->blend.stride,
@@ -450,8 +476,9 @@ _evas_vg_render(Evas_Object_Protected_Data *obj, Efl_Canvas_Vg_Object_Data *pd,
              EINA_LIST_FOREACH(cd->children, l, child)
                 _evas_vg_render(obj, pd, engine, output, context, child, clips, w, h, ector, do_async);
 
-             // Re-set original surface
-             ENFN->ector_begin(engine, output, context, ector, 0, 0, EINA_FALSE, do_async);
+             // Recover original surface
+             ector_buffer_pixels_set(ector, ppixels, pw, ph, pstride, pcspace, EINA_TRUE);
+             ector_surface_reference_point_set(ector, px, py);
 
              // Draw buffer to original surface.(Ector_Surface)
              ector_surface_draw_image(ector, cd->blend.buffer, 0, 0, alpha);
@@ -476,8 +503,8 @@ _evas_vg_render(Evas_Object_Protected_Data *obj, Efl_Canvas_Vg_Object_Data *pd,
 //renders a vg_tree to an offscreen buffer and push it to the cache.
 static void *
 _render_to_buffer(Evas_Object_Protected_Data *obj, Efl_Canvas_Vg_Object_Data *pd,
-                  void *engine, Efl_VG *root, int w, int h, void *buffer,
-                  Eina_Bool do_async, Eina_Bool cacheable)
+                  void *engine, Efl_VG *root, int w, int h, void *buffer, void *ckey,
+                  Eina_Bool do_async)
 {
    Ector_Surface *ector;
    RGBA_Draw_Context *context;
@@ -501,12 +528,14 @@ _render_to_buffer(Evas_Object_Protected_Data *obj, Efl_Canvas_Vg_Object_Data *pd
    evas_common_draw_context_set_color(context, 255, 255, 255, 255);
 
    //ector begin - end for drawing composite images.
-   //ENFN->ector_begin(engine, buffer, context, ector, 0, 0, EINA_FALSE, EINA_FALSE);
    _evas_vg_render_pre(obj, root, engine, buffer, context, ector, NULL, 255, NULL, 0);
-   //ENFN->ector_end(engine, buffer, context, ector, EINA_FALSE);
 
    //Actual content drawing
-   ENFN->ector_begin(engine, buffer, context, ector, 0, 0, EINA_TRUE, do_async);
+   if (!ENFN->ector_begin(engine, buffer, context, ector, 0, 0, do_async))
+     {
+        ERR("Failed ector begin!");
+        return NULL;
+     }
 
    //draw on buffer
    _evas_vg_render(obj, pd,
@@ -520,11 +549,23 @@ _render_to_buffer(Evas_Object_Protected_Data *obj, Efl_Canvas_Vg_Object_Data *pd
    ENFN->ector_end(engine, buffer, context, ector, do_async);
    evas_common_draw_context_free(context);
 
-   if (buffer_created && cacheable)
+   if (buffer_created && ckey)
      {
-        //Use root as a cache key.
-        ENFN->ector_surface_cache_set(engine, root, buffer);
-        pd->cached_frame_idx = pd->frame_idx;
+        //Drop ex invalid cache buffers.
+        if (pd->frame_idx == 0 && ckey != pd->ckeys[0])
+          {
+             if (pd->ckeys[0])
+               ENFN->ector_surface_cache_drop(engine, pd->ckeys[0]);
+             pd->ckeys[0] = ckey;
+          }
+        else if (pd->frame_idx == (int) (evas_cache_vg_anim_frame_count_get(pd->vg_entry) - 1)
+                 && ckey != pd->ckeys[1])
+          {
+             if (pd->ckeys[1])
+               ENFN->ector_surface_cache_drop(engine, pd->ckeys[1]);
+             pd->ckeys[1] = ckey;
+          }
+        ENFN->ector_surface_cache_set(engine, ckey, buffer);
      }
 
    return buffer;
@@ -537,6 +578,8 @@ _render_buffer_to_screen(Evas_Object_Protected_Data *obj,
                          int x, int y, int w, int h,
                          Eina_Bool do_async, Eina_Bool cacheable)
 {
+   if (!buffer) return;
+
    Eina_Bool async_unref;
 
    //Draw the buffer as image to canvas
@@ -566,8 +609,10 @@ _cache_vg_entry_render(Evas_Object_Protected_Data *obj,
    Vg_Cache_Entry *vg_entry = pd->vg_entry;
    Efl_VG *root;
    Eina_Position2D offset = {0, 0};  //Offset after keeping aspect ratio.
-   Eina_Bool drop_cache = EINA_FALSE;
    void *buffer = NULL;
+   void *key = NULL;
+
+   evas_cache_vg_entry_value_provider_update(pd->vg_entry, efl_key_data_get(obj->object, "_vg_value_providers"));
 
    // if the size changed in between path set and the draw call;
    if ((vg_entry->w != w) ||
@@ -601,7 +646,23 @@ _cache_vg_entry_render(Evas_Object_Protected_Data *obj,
         //Size is changed, cached data is invalid.
         if ((size.w != vg_entry->w) || (size.h != vg_entry->h))
           {
-             drop_cache = EINA_TRUE;
+//Not necessary, but this might be helpful for precise caching.
+#if 0
+             if (cacheable)
+               {
+                  //if the size doesn't match, drop previous cache surface.
+                  key = evas_cache_vg_surface_key_get(pd->vg_entry->root, vg_entry->w, vg_entry->h, 0);
+                  if (key) ENFN->ector_surface_cache_drop(engine, key);
+
+                  //Animatable... Try to drop the last frame image.
+                  int last_frame = (int) (evas_cache_vg_anim_frame_count_get(pd->vg_entry) - 1);
+                  if (last_frame > 0)
+                    {
+                       key = evas_cache_vg_surface_key_get(pd->vg_entry->root, vg_entry->w, vg_entry->h, last_frame);
+                       if (key) ENFN->ector_surface_cache_drop(engine, key);
+                    }
+               }
+#endif
              vg_entry = evas_cache_vg_entry_resize(vg_entry, size.w, size.h);
              evas_cache_vg_entry_del(pd->vg_entry);
              pd->vg_entry = vg_entry;
@@ -614,30 +675,25 @@ _cache_vg_entry_render(Evas_Object_Protected_Data *obj,
         if (offset.y > 0) offset.y /= 2;
         w = size.w;
         h = size.h;
-
      }
    root = evas_cache_vg_tree_get(vg_entry, pd->frame_idx);
    if (!root) return;
 
    if (cacheable)
      {
-        //if the size doesn't match, drop previous cache surface.
-        if (drop_cache)
-          ENFN->ector_surface_cache_drop(engine, (void *) root);
-        //Cache Hit!
-        else if (pd->frame_idx == pd->cached_frame_idx)
-          buffer = ENFN->ector_surface_cache_get(engine, (void *) root);
-        //Drop invalid one.
-        else
-          ENFN->ector_surface_cache_drop(engine, (void *) root);
+        key = evas_cache_vg_surface_key_get(root, w, h, pd->frame_idx);
+        if (key) buffer = ENFN->ector_surface_cache_get(engine, key);
      }
 
    if (!buffer)
-     buffer = _render_to_buffer(obj, pd, engine, root, w, h, NULL,
-                                do_async, cacheable);
+     {
+        buffer = _render_to_buffer(obj, pd, engine, root, w, h, NULL, key, do_async);
+     }
    else
-     //cache reference was increased when we get the cache.
-     ENFN->ector_surface_cache_drop(engine, (void *) root);
+     {
+        //cache reference was increased when we get the cache.
+        if (key) ENFN->ector_surface_cache_drop(engine, key);
+     }
 
    _render_buffer_to_screen(obj,
                             engine, output, context, surface,
@@ -650,8 +706,7 @@ static void
 _user_vg_entry_render(Evas_Object_Protected_Data *obj,
                       Efl_Canvas_Vg_Object_Data *pd,
                       void *engine, void *output, void *context, void *surface,
-                      int x, int y, int w, int h, Eina_Bool do_async,
-                      Eina_Bool cacheable)
+                      int x, int y, int w, int h, Eina_Bool do_async)
 {
    Vg_User_Entry *user_entry = pd->user_entry;
 
@@ -667,14 +722,13 @@ _user_vg_entry_render(Evas_Object_Protected_Data *obj,
    //if the buffer is not created yet
    void *buffer = NULL;
 
-   if (cacheable)
      buffer = ENFN->ector_surface_cache_get(engine, user_entry->root);
 
    if (!buffer)
      {
         // render to the buffer
         buffer = _render_to_buffer(obj, pd, engine, user_entry->root,
-                                   w, h, buffer, do_async, cacheable);
+                                   w, h, buffer, user_entry->root, do_async);
      }
    else
      {
@@ -682,8 +736,8 @@ _user_vg_entry_render(Evas_Object_Protected_Data *obj,
         if (pd->changed)
           buffer = _render_to_buffer(obj, pd, engine,
                                      user_entry->root,
-                                     w, h, buffer,
-                                     do_async, EINA_FALSE);
+                                     w, h, buffer, NULL,
+                                     do_async);
         //cache reference was increased when we get the cache.
         ENFN->ector_surface_cache_drop(engine, user_entry->root);
      }
@@ -692,7 +746,7 @@ _user_vg_entry_render(Evas_Object_Protected_Data *obj,
                             engine, output, context, surface,
                             buffer,
                             x, y, w, h,
-                            do_async, cacheable);
+                            do_async, EINA_TRUE);
 }
 
 static void
@@ -737,7 +791,7 @@ _efl_canvas_vg_object_render(Evas_Object *eo_obj EINA_UNUSED,
         _user_vg_entry_render(obj, pd,
                               engine, output, context, surface,
                               obj->cur->geometry.x + x, obj->cur->geometry.y + y,
-                              obj->cur->geometry.w, obj->cur->geometry.h, do_async, cacheable);
+                              obj->cur->geometry.w, obj->cur->geometry.h, do_async);
      }
    pd->changed = EINA_FALSE;
 }
@@ -749,7 +803,6 @@ _efl_canvas_vg_object_render_pre(Evas_Object *eo_obj,
 {
    Efl_Canvas_Vg_Object_Data *pd = type_private_data;
    int is_v, was_v;
-   Ector_Surface *s;
 
    if (obj->pre_render_done) return;
    obj->pre_render_done = EINA_TRUE;
@@ -769,12 +822,6 @@ _efl_canvas_vg_object_render_pre(Evas_Object *eo_obj,
                                             obj->cur->clipper->private_data);
      }
 
-   // FIXME: handle damage only on changed renderer.
-   // FIXME: Move this render_pre to efl_canvas_vg_render()
-   s = evas_ector_get(obj->layer->evas);
-   if (pd->root && s)
-     _evas_vg_render_pre(obj, pd->root, NULL, NULL, NULL, s, NULL, 255, NULL, 0);
-
    /* now figure what changed and add draw rects */
    /* if it just became visible or invisible */
    is_v = evas_object_is_visible(obj);
@@ -941,6 +988,30 @@ _efl_canvas_vg_object_efl_gfx_frame_controller_frame_duration_get(const Eo *eo_o
    return evas_cache_vg_anim_duration_get(pd->vg_entry);
 }
 
+Eina_Bool _efl_canvas_vg_object_efl_gfx_frame_controller_sector_set(Eo *obj EINA_UNUSED,
+                                                                    Efl_Canvas_Vg_Object_Data *pd,
+                                                                    const char *name,
+                                                                    int startframe,
+                                                                    int endframe)
+{
+   if (!pd->vg_entry) return EINA_FALSE;
+   if (!evas_cache_vg_anim_sector_set(pd->vg_entry, name, startframe, endframe))
+     return EINA_FALSE;
+   return EINA_TRUE;
+}
+
+Eina_Bool _efl_canvas_vg_object_efl_gfx_frame_controller_sector_get(const Eo *obj EINA_UNUSED,
+                                                                    Efl_Canvas_Vg_Object_Data *pd,
+                                                                    const char *name,
+                                                                    int *startframe,
+                                                                    int *endframe)
+{
+   if (!pd->vg_entry) return EINA_FALSE;
+   if (!evas_cache_vg_anim_sector_get(pd->vg_entry, name, startframe, endframe))
+     return EINA_FALSE;
+   return EINA_TRUE;
+}
+
 EOLIAN static Eina_Bool
 _efl_canvas_vg_object_efl_gfx_frame_controller_frame_set(Eo *eo_obj,
                                                          Efl_Canvas_Vg_Object_Data *pd,
@@ -972,7 +1043,7 @@ _efl_canvas_vg_object_default_size_get(const Eo *eo_obj EINA_UNUSED,
 }
 
 /* the actual api call to add a vector graphic object */
-EAPI Evas_Object *
+EAPI Eo *
 evas_object_vg_add(Evas *e)
 {
    e = evas_find(e);
@@ -1044,13 +1115,13 @@ _efl_ui_canvas_object_vg_fill_mode_to_evas_object_vg_fill_mode(Efl_Canvas_Vg_Fil
 }
 
 EAPI void
-evas_object_vg_fill_mode_set(Efl_VG *obj, Evas_Object_Vg_Fill_Mode fill_mode)
+evas_object_vg_fill_mode_set(Evas_Object *obj, Evas_Object_Vg_Fill_Mode fill_mode)
 {
    efl_canvas_vg_object_fill_mode_set(obj, _evas_object_vg_fill_mode_to_efl_ui_canvas_object_vg_fill_mode(fill_mode));
 }
 
 EAPI Evas_Object_Vg_Fill_Mode
-evas_object_vg_fill_mode_get(const Efl_VG *obj)
+evas_object_vg_fill_mode_get(const Evas_Object *obj)
 {
    return _efl_ui_canvas_object_vg_fill_mode_to_evas_object_vg_fill_mode(efl_canvas_vg_object_fill_mode_get(obj));
 }
