@@ -16,9 +16,6 @@
 
 #include <Ecore.h>
 
-#define EFL_INTERNAL_UNSTABLE
-#include "interfaces/efl_common_internal.h"
-
 #define MY_CLASS EVAS_CANVAS_CLASS
 
 #ifdef LKDEBUG
@@ -123,6 +120,33 @@ _efl_gfx_image_load_error_to_evas_load_error(Eina_Error err)
    return EVAS_LOAD_ERROR_GENERIC;
 }
 
+static Eina_Content*
+_markup_to_utf8(Eina_Content *from, const char *to_type)
+{
+   Eina_Content *ret = NULL;
+   Eina_Slice slice = eina_content_data_get(from);
+   char *utf8 = evas_textblock_text_markup_to_utf8(NULL, slice.mem);
+   if (utf8)
+     {
+        ret = eina_content_new((Eina_Slice)EINA_SLICE_STR_FULL(utf8), to_type);
+        free(utf8);
+     }
+   return ret;
+}
+
+static Eina_Content*
+_utf8_to_markup(Eina_Content *from, const char *to_type)
+{
+   Eina_Content *ret = NULL;
+   Eina_Slice slice = eina_content_data_get(from);
+   char *markup = evas_textblock_text_utf8_to_markup(NULL, slice.mem);
+   if (markup)
+     {
+        ret = eina_content_new((Eina_Slice)EINA_SLICE_STR_FULL(markup), to_type);
+        free(markup);
+     }
+   return ret;
+}
 
 EAPI int
 evas_init(void)
@@ -182,6 +206,9 @@ evas_init(void)
 
    _efl_gfx_image_load_error_init();
 
+   eina_content_converter_conversion_register("application/x-elementary-markup", "text/plain;charset=utf-8", _markup_to_utf8);
+   eina_content_converter_conversion_register("text/plain;charset=utf-8", "application/x-elementary-markup", _utf8_to_markup);
+
    return _evas_init_count;
 
  shutdown_filter:
@@ -225,6 +252,8 @@ evas_shutdown(void)
 
    evas_focus_shutdown();
 
+   evas_fonts_zero_free();
+
    evas_cache_vg_shutdown();
 
    evas_font_path_global_clear();
@@ -315,6 +344,7 @@ _evas_canvas_efl_object_constructor(Eo *eo_obj, Evas_Public_Data *e)
    eina_clist_init(&e->calc_done);
 
    efl_wref_add(efl_add(EFL_CANVAS_GESTURE_MANAGER_CLASS, eo_obj), &e->gesture_manager);
+   e->gmd = efl_data_scope_get(e->gesture_manager, EFL_CANVAS_GESTURE_MANAGER_CLASS);
 
 #define EVAS_ARRAY_SET(E, Array) \
    eina_array_step_set(&E->Array, sizeof (E->Array), \
@@ -333,6 +363,8 @@ _evas_canvas_efl_object_constructor(Eo *eo_obj, Evas_Public_Data *e)
    EVAS_ARRAY_SET(e, glyph_unref_queue);
    EVAS_ARRAY_SET(e, texts_unref_queue);
 
+   eina_array_step_set(&e->map_clip_objects, sizeof(e->map_clip_objects), 64);
+
    e->active_objects.version = EINA_ARRAY_VERSION;
    eina_inarray_step_set(&e->active_objects,
                          sizeof(Eina_Inarray),
@@ -614,6 +646,7 @@ _evas_canvas_efl_object_destructor(Eo *eo_e, Evas_Public_Data *e)
    eina_array_flush(&e->image_unref_queue);
    eina_array_flush(&e->glyph_unref_queue);
    eina_array_flush(&e->texts_unref_queue);
+   eina_array_flush(&e->map_clip_objects);
    eina_hash_free(e->focused_objects);
 
    SLKL(e->post_render.lock);
@@ -1061,9 +1094,6 @@ _image_data_unset(Evas_Object_Protected_Data *obj, Eina_List **list)
         data->engine_data =
           obj->layer->evas->engine.func->polygon_points_clear(ENC,
                                                               data->engine_data))
-   else CHECK(EVAS_CANVAS3D_TEXTURE_CLASS, Evas_Canvas3D_Texture_Data,
-        if (obj->layer->evas->engine.func->texture_free)
-          obj->layer->evas->engine.func->texture_free(ENC, data->engine_data))
    else return;
 #undef CHECK
    evas_object_ref(obj->object);
@@ -1120,10 +1150,8 @@ _image_data_regenerate(Evas_Object *eo_obj)
      }
    CHECK(EFL_CANVAS_IMAGE_INTERNAL_CLASS, Evas_Image_Data, _image_image_data_regenerate(eo_obj, obj, data))
    else CHECK(EFL_CANVAS_IMAGE_CLASS, Evas_Image_Data, _image_image_data_regenerate(eo_obj, obj, data))
-   else CHECK(EFL_CANVAS_SCENE3D_CLASS, Evas_Image_Data, _image_image_data_regenerate(eo_obj, obj, data))
    //else CHECK(EFL_CANVAS_VG_OBJECT_CLASS, Efl_Canvas_Vg_Object_Data,)
    //else CHECK(EFL_CANVAS_POLYGON_CLASS, Efl_Canvas_Polygon_Data,)
-   //else CHECK(EVAS_CANVAS3D_TEXTURE_CLASS, Evas_Canvas3D_Texture_Data,
 }
 
 EAPI void
@@ -1482,7 +1510,7 @@ _evas_pointer_data_add(Evas_Public_Data *edata, Evas_Device *pointer)
 }
 
 void
-_evas_pointer_data_remove(Evas_Public_Data *edata, Evas_Device *pointer)
+_evas_pointer_data_remove(Evas_Public_Data *edata, Evas_Device *pointer, Eina_Bool nofree)
 {
    Evas_Pointer_Data *pdata;
    Evas_Pointer_Seat *pseat;
@@ -1494,16 +1522,16 @@ _evas_pointer_data_remove(Evas_Public_Data *edata, Evas_Device *pointer)
           if (pdata->pointer == pointer)
             {
                pseat->pointers = eina_inlist_remove(pseat->pointers, EINA_INLIST_GET(pdata));
-               free(pdata);
+               if (!nofree) free(pdata);
                hit = pseat;
                break;
             }
      }
    EINA_SAFETY_ON_NULL_RETURN(hit);
    if (hit->pointers) return;
-   eina_list_free(hit->object.in);
+   hit->object.in = eina_list_free(hit->object.in);
    edata->seats = eina_inlist_remove(edata->seats, EINA_INLIST_GET(hit));
-   free(hit);
+   if (!nofree) free(hit);
 }
 
 Eina_List *
@@ -2014,5 +2042,43 @@ EWAPI const Efl_Event_Description _EVAS_CANVAS_EVENT_AXIS_UPDATE =
 EWAPI const Efl_Event_Description _EVAS_CANVAS_EVENT_VIEWPORT_RESIZE =
    EFL_EVENT_DESCRIPTION("viewport,resize");
 
+#define CHECK_ADD(var, ev, member) \
+  if ((var) == (ev)) \
+    { \
+       e->member = EINA_TRUE; \
+    }
+
+
+EOLIAN static Eina_Bool
+_evas_canvas_efl_object_event_callback_priority_add(Eo *obj, Evas_Public_Data *e, const Efl_Event_Description *desc, Efl_Callback_Priority priority, Efl_Event_Cb func, const void *user_data)
+{
+   CHECK_ADD(desc, EVAS_CANVAS_EVENT_RENDER_FLUSH_PRE, cb_render_flush_pre)
+   else CHECK_ADD(desc, EVAS_CANVAS_EVENT_RENDER_FLUSH_POST, cb_render_flush_post)
+   else CHECK_ADD(desc, EFL_CANVAS_SCENE_EVENT_RENDER_PRE, cb_render_pre)
+   else CHECK_ADD(desc, EFL_CANVAS_SCENE_EVENT_RENDER_POST, cb_render_post)
+
+   return efl_event_callback_priority_add(efl_super(obj, MY_CLASS), desc, priority, func, user_data);
+}
+
+EOLIAN static Eina_Bool
+_evas_canvas_efl_object_event_callback_array_priority_add(Eo *obj, Evas_Public_Data *e, const Efl_Callback_Array_Item *array, Efl_Callback_Priority priority, const void *user_data)
+{
+   for (int i = 0; array[i].desc; ++i)
+     {
+        CHECK_ADD(array[i].desc, EVAS_CANVAS_EVENT_RENDER_FLUSH_PRE, cb_render_flush_pre)
+        else CHECK_ADD(array[i].desc, EVAS_CANVAS_EVENT_RENDER_FLUSH_POST, cb_render_flush_post)
+        else CHECK_ADD(array[i].desc, EFL_CANVAS_SCENE_EVENT_RENDER_PRE, cb_render_pre)
+        else CHECK_ADD(array[i].desc, EFL_CANVAS_SCENE_EVENT_RENDER_POST, cb_render_post)
+     }
+   return efl_event_callback_array_priority_add(efl_super(obj, MY_CLASS), array, priority, user_data);
+}
+#undef CHECK_ADD
+#define EVAS_CANVAS_EXTRA_OPS \
+   EFL_OBJECT_OP_FUNC(efl_event_callback_priority_add, _evas_canvas_efl_object_event_callback_priority_add), \
+   EFL_OBJECT_OP_FUNC(efl_event_callback_array_priority_add, _evas_canvas_efl_object_event_callback_array_priority_add)
+
+
 #include "evas_stack.x"
 #include "canvas/evas_canvas_eo.c"
+#include "efl_canvas_pointer.eo.c"
+#include "efl_canvas_scene.eo.c"
